*********************
convert
*********************

:mod:`MTfit` contains a submodule :mod:`MTfit.convert` that can handle moment tensor conversions. Mostly it is used with the ``--convert`` flag for converting the moment tensor results to the different source  parameterisations. However it can be used separately, and the functions are described here.


.. automodule:: MTfit.convert.moment_tensor_conversion
    :members:
    